# Rearden [Data Science/Machine Learning Library]

This library was developed after the completion of "Data Science Specialist" specialization from Yandex Practicum.

The library consists of modules containing useful functions and classes which I came up with during completing the course and which simplify the process of conducting data analysis (data preprocessing and data vizualization) as well as hyperparameter selection via grid search.

This library has been used and verified in the [projects](https://github.com/spolivin/yandex_practicum_projects) completed during completing the Data Science course in Yandex Practicum.
